summaryrefslogtreecommitdiffstats
path: root/kmail/kmmessage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmmessage.h')
-rw-r--r--kmail/kmmessage.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kmail/kmmessage.h b/kmail/kmmessage.h
index 958d017e..a063ca1a 100644
--- a/kmail/kmmessage.h
+++ b/kmail/kmmessage.h
@@ -131,7 +131,7 @@ public:
*/
void setUnencryptedMsg( KMMessage* unencrypted );
- /** Returns TRUE if the message contains an unencrypted copy of itself. */
+ /** Returns TRUE if the message tqcontains an unencrypted copy of itself. */
bool hasUnencryptedMsg() const { return 0 != mUnencryptedMsg; }
/** Returns an unencrypted copy of this message or 0 if none exists. */
@@ -150,13 +150,13 @@ public:
}
/** Mark the message as deleted */
- void del() { setStatus(KMMsgStatusDeleted); }
+ void del() { seStatus(KMMsgStatusDeleted); }
/** Undelete the message. Same as touch */
- void undel() { setStatus(KMMsgStatusOld); }
+ void undel() { seStatus(KMMsgStatusOld); }
/** Touch the message - mark it as read */
- void touch() { setStatus(KMMsgStatusOld); }
+ void touch() { seStatus(KMMsgStatusOld); }
/** Create a new message that is a reply to this message, filling all
required header fields with the proper values. The returned message
@@ -210,9 +210,9 @@ public:
void sanitizeHeaders( const TQStringList& whiteList = TQStringList() );
/** Parse the string and create this message from it. */
- void fromDwString(const DwString& str, bool setStatus=false);
- void fromString(const TQCString& str, bool setStatus=false);
- void fromByteArray(const TQByteArray & ba, bool setStatus=false);
+ void fromDwString(const DwString& str, bool seStatus=false);
+ void fromString(const TQCString& str, bool seStatus=false);
+ void fromByteArray(const TQByteArray & ba, bool seStatus=false);
/** Return the entire message contents in the DwString. This function
is *fast* even for large message since it does *not* involve a
@@ -545,7 +545,7 @@ public:
*/
void setBodyFromUnicode( const TQString & str, DwEntity *entity = 0 );
- /** Returns the body part decoded to unicode.
+ /** Returns the body part decoded to tqunicode.
**/
TQString bodyToUnicode(const TQTextCodec* codec=0) const;
@@ -663,13 +663,13 @@ public:
/**
* Delete a body part with the specified part index.
* A dummy body part with the text "the attachment foo was deleted" will replace the old part.
*/
bool deleteBodyPart( int partIndex );
/** Set "Status" and "X-Status" fields of the message from the
* internal message status. */
- void setStatusFields();
+ void seStatusFields();
/** Generates the Message-Id. It uses either the Message-Id suffix
* defined by the user or the given email address as suffix. The address
@@ -679,7 +679,7 @@ public:
/** Convert '<' into "&lt;" resp. '>' into "&gt;" in order to
* prevent their interpretation by KHTML.
* Does *not* use the Qt replace function but runs a very fast C code
* the same way as lf2crlf() does.
*/
static TQCString html2source( const TQCString & src );
@@ -713,7 +713,7 @@ public:
bool removeLineBreaks = false );
/** Converts the email address(es) to (a) nice HTML mailto: anchor(s).
- * If stripped is TRUE then the visible part of the anchor contains
+ * If stripped is TRUE then the visible part of the anchor tqcontains
* only the name part and not the given emailAddr.
*/
static TQString emailAddrAsAnchor(const TQString& emailAddr,
@@ -746,7 +746,7 @@ public:
static TQString guessEmailAddressFromLoginName( const TQString& userName );
/**
- * Given argument msg add quoting characters and relayout for max width maxLength
+ * Given argument msg add quoting characters and retqlayout for max width maxLength
* @param msg the string which it to be quoted
* @param maxLineLength reformat text to be this amount of columns at maximum, adding
* linefeeds at word boundaries to make it fit.
@@ -760,7 +760,7 @@ public:
static const TQStringList &preferredCharsets();
/** Replaces every occurrence of "${foo}" in @p s with headerField("foo") */
- TQString replaceHeadersInString( const TQString & s ) const;
+ TQString tqreplaceHeadersInString( const TQString & s ) const;
/** Get the message charset.*/
TQCString charset() const;
@@ -825,8 +825,8 @@ public:
/** Status of the message. */
KMMsgStatus status() const { return mStatus; }
/** Set status and mark dirty. */
- void setStatus(const KMMsgStatus status, int idx = -1);
- void setStatus(const char* s1, const char* s2=0) { KMMsgBase::setStatus(s1, s2); }
+ void seStatus(const KMMsgStatus status, int idx = -1);
+ void seStatus(const char* s1, const char* s2=0) { KMMsgBase::seStatus(s1, s2); }
/** Set encryption status of the message. */
void setEncryptionState(const KMMsgEncryptionState, int idx = -1);
@@ -847,8 +847,8 @@ public:
/** Links this message to @p aMsg, setting link type to @p aStatus. */
void link(const KMMessage *aMsg, KMMsgStatus aStatus);
/** Returns the information for the Nth link into @p retMsg
- * and @p retStatus. */
- void getLink(int n, ulong *retMsgSerNum, KMMsgStatus *retStatus) const;
+ * and @p reStatus. */
+ void getLink(int n, ulong *retMsgSerNum, KMMsgStatus *reStatus) const;
/** Convert wildcards into normal string */
TQString formatString(const TQString&) const;
@@ -886,7 +886,7 @@ public:
/** Returns message body with quoting header and indented by the
given indentation string. This is suitable for including the message
in another message of for replies, forwards. The header string is
- a template where the following fields are replaced with the
+ a template where the following fields are tqreplaced with the
corresponding values:
<pre>
%D: date of this message
@@ -969,7 +969,7 @@ private:
KMMessage* mUnencryptedMsg;
DwBodyPart* mLastUpdated;
int mCursorPos;
- KMMsgInfo* mMsgInfo; // used to remember the KMMsgInfo object this KMMessage replaced in the KMMsgList
+ KMMsgInfo* mMsgInfo; // used to remember the KMMsgInfo object this KMMessage tqreplaced in the KMMsgList
static TQValueList<KMMessage*> sPendingDeletes;
};
@@ -663,13 +663,13 @@ public:
/**
* Delete a body part with the specified part index.
- * A dummy body part with the text "the attachment foo was deleted" will replace the old part.
+ * A dummy body part with the text "the attachment foo was deleted" will tqreplace the old part.
*/
bool deleteBodyPart( int partIndex );
@@ -679,7 +679,7 @@ public:
/** Convert '<' into "&lt;" resp. '>' into "&gt;" in order to
* prevent their interpretation by KHTML.
- * Does *not* use the Qt replace function but runs a very fast C code
+ * Does *not* use the Qt tqreplace function but runs a very fast C code
* the same way as lf2crlf() does.
*/